@@ -2,6 +2,7 @@ import sys
 import time
 
 from celery.exceptions import TaskRevokedError
+
 from dagster import check
 from dagster.core.errors import DagsterSubprocessError
 from dagster.core.events import DagsterEvent, EngineEventData
@@ -149,7 +150,7 @@ def core_celery_execution_loop(pipeline_context, execution_plan, step_execution_
                 except Exception:
                     yield DagsterEvent.engine_event(
                         pipeline_context,
-                        "Encountered error during celery task submission.".format(),
+                        "Encountered error during celery task submission.",
                         event_specific_data=EngineEventData.engine_error(
                             serializable_error_info_from_exc_info(sys.exc_info()),
                         ),
